@@ -41,7 +41,7 @@ class SelfDocAPI < Debci::App
       if lines.first && lines.first.strip == ""
         lines.first.shift
       end
-      lines.first =~ /^\s+/; prefix = $&
+      lines.first =~ /^\s+/; prefix = ::Regexp.last_match(0)
       if prefix
         lines.map! do |line|
           line.sub(/^#{prefix}/, '')
@@ -153,6 +153,15 @@ module Debci
         redirect "user/:user/retry/#{params[:run_id]}"
       end
 
+      doc <<-EOF
+      Retries the test with the given ID.
+      EOF
+      post '/retry/:run_id' do
+        job = get_job_to_retry(params[:run_id])
+        job.retry
+        200
+      end
+
       doc <<-EOF
       Retrieves results for your test requests.
 
@@ -227,8 +236,8 @@ module Debci
           jobs = jobs.where('updated_at >= ?', since)
         end
         data = {
-          "until": jobs.map(&:created_at).max.to_i,
-          "results": jobs,
+          until: jobs.map(&:created_at).max.to_i,
+          results: jobs,
         }
         headers['Content-Type'] = 'application/json'
         data.to_json
@@ -255,9 +264,6 @@ module Debci
         test_requests = load_json(params[:tests])
         errors = validate_batch_test(test_requests)
         if errors.empty?
-          request['tests'].each do |t|
-            t['extra-apt-sources'] = get_extra_apt_sources_entries(t['extra-apt-sources'])
-          end
           request_batch_tests(test_requests, @user, @priority)
           201
         else
@@ -344,9 +350,6 @@ module Debci
         tests = load_json(params[:tests])
         errors = validate_tests(tests)
         if errors.empty?
-          tests.each do |test|
-            test['extra-apt-sources'] = get_extra_apt_sources_entries(test['extra-apt-sources'])
-          end
           self.request_tests(tests, suite, arch, @user, @priority)
           201
         else
@@ -396,7 +399,6 @@ module Debci
         end
 
         package = Debci::Package.find_or_create_by!(name: pkg)
-        extra_apt_sources = get_extra_apt_sources_entries(extra_apt_sources)
         job = Debci::Job.create!(
             package: package,
             suite: params[:suite],
@@ -441,7 +443,7 @@ module Debci
     def load_json(param)
       begin
         raise "No tests" if param.nil?
-        str = param.is_a?(Hash) && File.read(param[:tempfile]) || param
+        str = (param.is_a?(Hash) && File.read(param[:tempfile])) || param
         JSON.parse(str)
       rescue JSON::ParserError => error
         halt(400, "Invalid JSON: #{error}")
@@ -458,16 +460,6 @@ module Debci
         halt(403, "Invalid key\n")
       end
     end
-
-    def get_extra_apt_sources_entries(extra_apt_sources)
-      return if extra_apt_sources.nil?
-      extra_apt_sources_entries = []
-      extra_apt_sources.each do |extra_apt_source|
-        extra_apt_sources_entries.push(Debci.extra_apt_sources_list.find(extra_apt_source).entry)
-      end
-      extra_apt_sources_entries
-    end
-
   end
 
 end
