@@ -11,8 +11,12 @@ module Debci
       if package.backend && Debci::AMQP.queue_exists?(arch, package.backend)
         package.backend
       else
-        Debci.config.backend
+        default
       end
     end
+
+    def self.default
+      Debci.config.backend
+    end
   end
 end
