@@ -1,6 +1,8 @@
+require 'active_support/core_ext/numeric/bytes'
 require "debci/app"
 require "debci/package"
 require 'debci/html_helpers'
+require 'debci/log'
 
 module Debci
   class Frontend < Debci::App
@@ -52,6 +54,8 @@ module Debci
         halt 404
       end
       @moretitle = @package.name
+
+      refresh!
       erb :package
     end
     get "/:prefix/:package" do
@@ -77,10 +81,39 @@ module Debci
       # pagination
       results = get_page_params(@history, params[:page], 500)
 
+      refresh!
       erb :history, locals: { results: results }
     end
     get "/:prefix/:package/:suite/:architecture" do
       redirect "#{request.path}/"
     end
+
+    get "/:prefix/:package/:suite/:architecture/:run_id/" do
+      halt 404 unless params[:package].start_with?(params[:prefix])
+      @package = Debci::Package.find_by_name(params[:package])
+      halt 404 unless @package
+
+      begin
+        @job = @package.jobs.where(
+          arch: params[:architecture],
+          suite: params[:suite]
+        ).find(params[:run_id])
+      rescue ActiveRecord::RecordNotFound
+        halt 404
+      end
+
+      halt(404) if @job.files_purged?
+
+      @too_large = @job.log_size.to_i > 500.kilobytes
+
+      log_file = (@job.autopkgtest_dir / "log.gz").to_s
+      @log = Debci::Log.new(log_file)
+      @log.parse unless @too_large
+      erb :log_viewer
+    end
+
+    get "/:prefix/:package/:suite/:architecture/:run_id" do
+      redirect "#{request.path}/"
+    end
   end
 end
