@@ -14,6 +14,7 @@ module Debci
     include Debci::HTMLHelpers
     include Debci::Validators::APTSource
 
+    use Rack::MethodOverride
     use OmniAuth::Builder do
       if development?
         provider :developer,
@@ -155,17 +156,23 @@ module Debci
     end
 
     get '/:user/getkey' do
-      erb :getkey
+      redirect "/user/#{@user.username}/keys"
     end
 
-    post '/:user/getkey' do
-      if @user
-        key = Debci::Key.reset!(@user)
-        headers['Content-Type'] = 'text/plain'
-        [201, key.key]
-      else
-        403
-      end
+    get '/:user/keys' do
+      @keys = Debci::Key.where(user: @user)
+      erb :keys
+    end
+
+    post '/:user/keys' do
+      @key = Debci::Key.create!(params.update(user: @user))
+      @keys = Debci::Key.where(user: @user)
+      erb :keys
+    end
+
+    delete '/:user/keys' do
+      Debci::Key.where(user: @user).find(params[:id]).destroy!
+      redirect "/user/#{@user.username}/keys"
     end
 
     class InvalidRequest < RuntimeError
@@ -230,6 +237,7 @@ module Debci
       # pagination
       results = get_page_params(@history, params[:page], 20)
 
+      refresh!
       erb :self_service_history, locals: { arch_filter: arch_filter, suite_filter: suite_filter, package_filter: package_filter, trigger_filter: trigger_filter,
                                            is_private_filter: is_private_filter, disable_private_filter: disable_private_filter, results: results }
     end
