@@ -12,9 +12,11 @@ module Debci
       set :archs, Debci.config.arch_list
     end
 
+    PER_PAGE = 200
+
     def filter_and_paginate(jobs)
       query = params.select { |k| [:arch, :suite].include?(k.to_sym) }
-      get_page_params(jobs.where(query), params[:page], 200)
+      get_page_params(jobs.where(query), params[:page], PER_PAGE)
     end
 
     before do
@@ -27,41 +29,22 @@ module Debci
 
     get "/alerts/" do
       @tmpfail = filter_and_paginate(Debci::Job.tmpfail)
-      @alert_number = Debci::Job.tmpfail.length
+      @alert_number = @tmpfail.total_records
 
       erb :status_alerts
     end
 
     get "/failing/" do
       @jobs = filter_and_paginate(Debci::Job.fail)
-      @failing_number = Debci::Job.fail.length
-      @packages_per_page = Debci.config.failing_packages_per_page
-
+      @failing_number = @jobs.total_records
       erb :status_failing
     end
 
     get "/pending/" do
       @pending = filter_and_paginate(Debci::Job.pending)
-      @status_per_page = Debci.config.pending_status_per_page.to_i
-      @suites_jobs = Debci.config.suite_list.map do |x|
-        [x, Debci::Job.pending.where(suite: x).count]
-      end.to_h
-
       erb :status_pending_jobs
     end
 
-    get "/pending/:suite/" do
-      suite = params[:suite]
-      @pending = Debci::Job.pending.where(suite: suite)
-      @pending_jobs = Debci::Job.pending.count
-      @status_per_page = Debci.config.pending_status_per_page.to_i
-      @suites_jobs = Debci.config.suite_list.map do |x|
-        [x, Debci::Job.pending.where(suite: x).count]
-      end.to_h
-
-      erb :status_pending_jobs, locals: { results: @pending }
-    end
-
     get "/reject_list/" do
       @reject_list = Debci.reject_list
       erb :reject_list
