@@ -19,7 +19,7 @@ module Debci
         @result_json ||= root / 'packages' / suite / arch / package.prefix / package.name / "#{run_id}.json"
       end
 
-      def cleanup
+      def purge_files
         autopkgtest_dir.rmtree if autopkgtest_dir.directory?
         debci_log.unlink if debci_log.exist?
         result_json.unlink if result_json.exist?
