@@ -77,7 +77,7 @@ debci_salsa_client_secret="${debci_salsa_client_secret:-}"
 debci_secrets_dir=${debci_secrets_dir:-$(readlink -f "${debci_base_dir}/secrets")}
 
 shared_short_options='c:s:a:b:d:m:hq'
-shared_long_options='config:,suite:,arch:,backend:,data-dir:,amqp:,mirror:,help,quiet'
+shared_long_options='config:,suite:,arch:,backend:,data-dir:,amqp:,mirror:,keyring:,help,quiet'
 
 usage_shared_options="Common options:
 
@@ -95,6 +95,8 @@ usage_shared_options="Common options:
                             AMQP server to connect to (default: ${debci_amqp_server})
   -m URL, --mirror URL      selects which mirror to use for APT-related actions,
                             i.e. creating test backends, pulling sources files, etc.
+  --keyring KEY             specify a custom APT repository keyring, used when
+                            creating test backends
   -q, --quiet               prevents debci from producing any output on stdout
   --help                    show this usage message
 "
@@ -137,6 +139,9 @@ for arg in "$@"; do
       -m|--mirror)
         var=debci_mirror
         ;;
+      --keyring)
+        var=debci_keyring
+        ;;
       -q|--quiet)
         export debci_quiet=true
         ;;
@@ -167,6 +172,7 @@ export debci_gnupg_dir="${debci_base_dir}/gnupg"
 debci_bin_dir="${debci_base_dir}/bin"
 
 export debci_log_dir="${debci_base_dir}/log"
+export debci_results_dir="${debci_data_basedir}/results"
 
 debci_user=$(stat -c %U "${debci_data_basedir}")
 debci_uid=$(stat -c %u "${debci_data_basedir}")
@@ -197,7 +203,6 @@ debci_lock_dir=${debci_lock_dir:-/var/lock}
 
 # per-suite/architecture lock/timestamp files
 export debci_testbed_timestamp=${debci_lock_dir}/debci-testbed-${debci_suite}-${debci_arch}-${debci_backend}.stamp
-export debci_chdist_lock=${debci_lock_dir}/debci-chdist-${debci_suite}-${debci_arch}.lock
 
 # global lock/timestamp files
 export debci_generate_index_lock=${debci_lock_dir}/debci-generate-index.lock
@@ -205,9 +210,17 @@ export debci_generate_index_lock=${debci_lock_dir}/debci-generate-index.lock
 # data retention policy (numbers of days)
 debci_data_retention_days=${debci_data_retention_days:-180}
 
+# disk storage limit per package (MB)
+debci_disk_storage_limit=${debci_disk_storage_limit:-200}
+
 # extra arguments for autopkgtest
 debci_autopkgtest_args="${debci_autopkgtest_args:-}"
 
+# extra arguments for backends
+debci_autopkgtest_args_null="${debci_autopkgtest_args_null:-}"
+debci_autopkgtest_args_lxc="${debci_autopkgtest_args_lxc:-}"
+debci_autopkgtest_args_qemu="${debci_autopkgtest_args_qemu:-}"
+
 # session secret for the web interface
 debci_session_secret="${debci_session_secret:-}"
 
