@@ -1,5 +1,6 @@
 require 'spec_helper'
 require 'debci/data'
+require 'magic'
 
 RSpec.shared_context 'export/import' do
   let(:package) { Debci::Package.create!(name: 'rake') }
@@ -58,8 +59,8 @@ describe Debci::Data::Export do
   end
 
   it 'creates a valid output_tarball' do
-    mime_type = `file --brief --mime #{output_tarball}`.strip
-    expect(mime_type).to eq('application/x-tar; charset=binary')
+    mime_type = Magic.guess_file_mime_type(output_tarball)
+    expect(mime_type).to eq('application/x-tar')
   end
 
   it 'exports history data file' do
@@ -71,7 +72,6 @@ describe Debci::Data::Export do
     expect(exported_files).to include("autopkgtest/unstable/#{arch}/r/rake/9999/worker")
   end
   it 'exports package data' do
-    system('cp', output_tarball, '/tmp/')
     expect(exported_files).to include("packages/unstable/#{arch}/r/rake/9999.log")
   end
 end
