@@ -132,4 +132,32 @@ describe Debci::Frontend do
       expect(last_response.body).to_not match('current-package')
     end
   end
+
+  context "displaying logs" do
+    it 'formats logs for viewing' do
+      job = @rake.jobs.create!(requestor: theuser, suite: "unstable", arch: "arm64")
+      job.autopkgtest_dir.mkpath
+      Zlib::GzipWriter.open(job.autopkgtest_dir / "log.gz") do |f|
+        f.write(File.read("#{__dir__}/log_spec/foobar.fake.log"))
+      end
+
+      get "/packages/r/rake/unstable/arm64/#{job.run_id}/"
+      expect(last_response.status).to eq(200)
+      expect(last_response.body).to match(/starting date and time/)
+    end
+
+    it 'renders log expired template for expired logs' do
+      job = @rake.jobs.create!(requestor: theuser, suite: "unstable", arch: "arm64", files_purged: true)
+      get "/packages/r/rake/unstable/arm64/#{job.run_id}/"
+      expect(last_response.status).to eq(404)
+      expect(last_response.body).to match(/expired/i)
+    end
+
+    it "doesn't try to display logs > 500KB'" do
+      job = @rake.jobs.create!(requestor: theuser, suite: "unstable", arch: "arm64", log_size: 600.kilobytes)
+      get "/packages/r/rake/unstable/arm64/#{job.run_id}/"
+      expect(last_response.status).to eq(200)
+      expect(last_response.body).to match(/Please download the raw log instead/i)
+    end
+  end
 end
