@@ -113,6 +113,27 @@ describe Debci::Job do
 
       new_job.enqueue
     end
+    it 'saves requested backend in the database' do
+      queue = double("Queue")
+      expect(Debci::AMQP).to receive(:get_queue).and_return(queue)
+      expect(queue).to receive(:publish)
+
+      new_job.enqueue
+      new_job.reload
+      expect(new_job.requested_backend).to_not be_nil
+    end
+  end
+
+  context 'reporting backend' do
+    it 'reports default backend if nil' do
+      job = Debci::Job.new
+      expect(job.backend).to eq(Debci.config.backend)
+    end
+
+    it 'report stored backend if any' do
+      job = Debci::Job.new(requested_backend: "foobar")
+      expect(job.backend).to eq("foobar")
+    end
   end
 
   let(:suite) { 'unstable' }
@@ -294,14 +315,14 @@ describe Debci::Job do
       File.join(tmpdir, 'autopkgtest-incoming', original_job.id.to_s)
     end
 
+    let(:past) { Time.now - 7.days }
     before(:each) do
       FileUtils.mkdir_p File.dirname(incoming)
       FileUtils.cp_r 'spec/debci/job_spec/autopkgtest-incoming', incoming
+      FileUtils.touch(File.join(incoming, 'duration'), mtime: past)
       allow_any_instance_of(Debci::Config).to receive(:autopkgtest_basedir).and_return(File.join(tmpdir, 'autopkgtest'))
     end
-    let(:past) { Time.now - 7.days }
     let(:job) do
-      FileUtils.touch(File.join(incoming, 'duration'), mtime: past)
       Debci::Job.receive(incoming)
     end
 
@@ -355,6 +376,18 @@ describe Debci::Job do
       expect(job.artifacts_size).to be_an(Integer)
     end
 
+    [
+      [nil, nil, 0],
+      [nil, 1, 1],
+      [1, nil, 1],
+      [10, 10, 20],
+    ].each do |log, artifacts, total|
+      it "calculates total disk usage #{log}+#{artifacts}=#{total}" do
+        job = Debci::Job.new(log_size: log, artifacts_size: artifacts)
+        expect(job.disk_usage).to eq(total)
+      end
+    end
+
     let(:second_original_job) do
       Debci::Job.create!(
         package: package,
@@ -412,6 +445,26 @@ describe Debci::Job do
       expect(job.autopkgtest_dir).to_not exist
       expect(job.debci_log).to_not exist
       expect(job.result_json).to_not exist
+      expect(job.files_purged).to be true
+    end
+
+    context 'with incomplete results' do
+      it 'resists missing log.gz' do
+        (Pathname(incoming) / "log.gz").delete
+        expect(job.log_size).to be_nil
+        expect(job.artifacts_size).to_not be_nil
+      end
+      it 'resists a completely empty results directory' do
+        Pathname(incoming).glob("*").each(&:delete)
+        expect(job.log_size).to be_nil
+        expect(job.artifacts_size).to be_nil
+        expect(job.status).to eq("tmpfail")
+      end
+      it 'resists missing all files but exitcode' do
+        Pathname(incoming).glob("*").each { |f| f.delete unless f.basename.to_s == 'exitcode' }
+        expect(job.status).to_not be_nil
+        expect(job.duration_seconds).to eq(0)
+      end
     end
   end
 
@@ -567,22 +620,4 @@ describe Debci::Job do
       expect { Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now, requestor: theuser) }.to_not raise_error
     end
   end
-
-  context 'determining expiration' do
-    it 'is expired after data retention period' do
-      allow_any_instance_of(Debci::Config).to receive(:data_retention_days).and_return(90)
-      job = Debci::Job.new(date: Time.now - 91.days)
-      expect(job).to be_expired
-    end
-    it 'is not expired if recent' do
-      allow_any_instance_of(Debci::Config).to receive(:data_retention_days).and_return(90)
-      job = Debci::Job.new(date: Time.now - 1.day)
-      expect(job).to_not be_expired
-    end
-    it 'is not expired without a data retention period' do
-      allow_any_instance_of(Debci::Config).to receive(:data_retention_days).and_return(nil)
-      job = Debci::Job.new(date: Time.now - 1.year)
-      expect(job).to_not be_expired
-    end
-  end
 end
