@@ -152,31 +152,36 @@ describe Debci::SelfService do
     end
   end
 
-  context 'getting a key' do
-    it "can't get a key with invalid auth" do
-      keys = Debci::Key.count
-
-      post '/user/foo@bar.com/getkey'
-      expect(last_response.status).to eq(302) # redirected to login page
-
-      expect(Debci::Key.count).to eq(keys)
-    end
-
-    it 'gets a key when user is logged in' do
+  context 'managing keys' do
+    before(:each) do
       login('foo@bar.com')
-      post '/user/foo@bar.com/getkey'
-      expect(last_response.status).to eq(201)
-
-      user = Debci::User.find_by(username: 'foo@bar.com')
-      key = user.keys.first
-      expect(key).to_not be_nil
     end
+    let(:user) { Debci::User.find_by_username("foo@bar.com") }
 
-    it 'displays a user-friendly page' do
-      login('foo@bar.com')
+    it "redirects old getkey endpoint" do
       get '/user/foo@bar.com/getkey'
-      expect(last_response.status).to eq(200)
-      expect(last_response.content_type).to match('text/html')
+      expect(last_response.status).to eq(302)
+      expect(last_response.location).to match(%r{/user/foo@bar.com/keys$})
+    end
+
+    it 'lists keys' do
+      Debci::Key.create!(user: user, description: "one key")
+      Debci::Key.create!(user: user, description: "another key")
+      get '/user/foo@bar.com/keys'
+      expect(last_response.body).to match("one key")
+      expect(last_response.body).to match("another key")
+    end
+
+    it 'creates keys' do
+      post '/user/foo@bar.com/keys', description: "my new key"
+      expect(last_response.body).to match("my new key")
+      expect(Debci::Key.where(user: user, description: "my new key")).to exist
+    end
+
+    it 'deletes keys' do
+      key = Debci::Key.create!(user: user)
+      delete '/user/foo@bar.com/keys', id: key.id
+      expect(Debci::Key.where(user: user, id: key.id)).to_not exist
     end
   end
 
