@@ -5,7 +5,7 @@
 test_almost_empty_data_dir() {
   echo "1" > "$debci_data_basedir/schema_version"
   rc=0
-  debci generate-html || rc=$?
+  debci html update || rc=$?
   assertEquals 0 $rc
 }
 
