@@ -145,6 +145,7 @@ stop_rabbitmq_server() {
 }
 
 TEST_WORKER_PID=''
+TEST_PUBLISHER_PID=''
 
 start_worker() {
   export WORKER_START_TIMESTAMP=$(date +%s)
@@ -154,6 +155,8 @@ start_worker() {
   export debci_poll_interval="0.1"
   PATH="$testbin:$PATH" debci worker &
   TEST_WORKER_PID=$!
+  PATH="$testbin:$PATH" debci publisher &
+  TEST_PUBLISHER_PID=$!
   sleep 0.1
   if [ -n "${DEBUG:-}" ]; then
     echo "started worker $TEST_WORKER_PID"
@@ -168,6 +171,8 @@ stop_worker() {
     fi
     kill $TEST_WORKER_PID 2>/dev/null && wait $TEST_WORKER_PID || true
     TEST_WORKER_PID=
+    kill $TEST_PUBLISHER_PID 2>/dev/null && wait $TEST_PUBLISHER_PID || true
+    TEST_PUBLISHER_PID=
   fi
 }
 
